BUILD_BIT = '64bit'
BUILD_CPU = 'ARMv8 (64-bit) Family 8 Model D4C Revision   0, Qualcomm Technologies Inc'
BUILD_DATE = '2024-10-24'
BUILD_MACHINE = 'ARM64'
BUILD_OS = 'Microsoft Windows 11 Pro'
BUILD_TIME = '14:41'
BUILD_TYPE = ''
COMPILER_VERSION = 'clang version 18.1.8'
CYTHON_VERSION = '3.0.11'
LINKER_VERSION = 'LLD 18.1.8 (compatible with GNU linkers)'
NVCC_VERSION = ''
PYTHON_VERSION = '3.11.10'
lib_base = '2022.06-1'
lib_basedevel = '2022.12-2'
lib_bash = '5.2.037-1'
lib_bashcompletion = '2.14.0-1'
lib_binutils = '2.43.1-1'
lib_bison = '3.8.2-5'
lib_brotli = '1.1.0-1'
lib_bsdtar = '3.7.7-1'
lib_bzip2 = '1.0.8-4'
lib_cacertificates = '20240203-2'
lib_coreutils = '8.32-5'
lib_curl = '8.10.1-1'
lib_dash = '0.5.12-1'
lib_db = '6.2.32-5'
lib_diffstat = '1.66-1'
lib_diffutils = '3.10-1'
lib_dos2unix = '7.5.2-1'
lib_etcupdate = '2.3.99-1'
lib_file = '5.45-3'
lib_filesystem = '2023.02.07-2'
lib_findutils = '4.10.0-2'
lib_flex = '2.6.4-3'
lib_gawk = '5.3.1-1'
lib_gcclibs = '13.3.0-1'
lib_gdbm = '1.24-1'
lib_getent = '2.18.90-4'
lib_gettext = '0.22.4-1'
lib_gmp = '6.3.0-1'
lib_gnupg = '2.4.5-1'
lib_grep = '1~3.0-6'
lib_gzip = '1.13-1'
lib_heimdallibs = '7.8.0-5'
lib_inetutils = '2.5-2'
lib_info = '7.1.1-1'
lib_less = '661-1'
lib_libargp = '20110921-4'
lib_libasprintf = '0.22.4-1'
lib_libassuan = '2.5.7-1'
lib_libbz2 = '1.0.8-4'
lib_libcurl = '8.10.1-1'
lib_libdb = '6.2.32-5'
lib_libedit = '20240517_3.1-1'
lib_libexpat = '2.6.3-1'
lib_libffi = '3.4.6-1'
lib_libgcrypt = '1.11.0-1'
lib_libgdbm = '1.24-1'
lib_libgettextpo = '0.22.4-1'
lib_libgnutls = '3.8.7-1'
lib_libgpgerror = '1.50-1'
lib_libhogweed = '3.10-1'
lib_libiconv = '1.17-1'
lib_libidn2 = '2.3.7-1'
lib_libintl = '0.22.4-1'
lib_libksba = '1.6.7-1'
lib_liblz4 = '1.10.0-1'
lib_liblzma = '5.6.3-1'
lib_libnettle = '3.10-1'
lib_libnghttp2 = '1.63.0-1'
lib_libnpth = '1.7-1'
lib_libopenssl = '3.3.2-1'
lib_libp11kit = '0.25.5-2'
lib_libpcre = '8.45-4'
lib_libpcre28 = '10.44-1'
lib_libpsl = '0.21.5-2'
lib_libreadline = '8.2.013-1'
lib_libsqlite = '3.46.1-1'
lib_libssh2 = '1.11.0-1'
lib_libtasn1 = '4.19.0-1'
lib_libunistring = '1.2-1'
lib_libutillinux = '2.35.2-4'
lib_libxcrypt = '4.4.36-1'
lib_libzstd = '1.5.6-1'
lib_m4 = '1.4.19-2'
lib_make = '4.4.1-2'
lib_mingww64clangaarch64adwaitaicontheme = '47.0-1'
lib_mingww64clangaarch64adwaitaiconthemelegacy = '46.2-1'
lib_mingww64clangaarch64atk = '2.54.0-1'
lib_mingww64clangaarch64brotli = '1.1.0-2'
lib_mingww64clangaarch64bzip2 = '1.0.8-3'
lib_mingww64clangaarch64cairo = '1.18.2-1'
lib_mingww64clangaarch64clang = '18.1.8-1'
lib_mingww64clangaarch64clanganalyzer = '18.1.8-1'
lib_mingww64clangaarch64clanglibs = '18.1.8-1'
lib_mingww64clangaarch64clangtoolsextra = '18.1.8-1'
lib_mingww64clangaarch64compilerrt = '18.1.8-1'
lib_mingww64clangaarch64crtgit = '12.0.0.r360.gac299df46-1'
lib_mingww64clangaarch64cython = '3.0.11-1'
lib_mingww64clangaarch64eglheaders = '1.5.r255.9ab6036-1'
lib_mingww64clangaarch64expat = '2.6.3-1'
lib_mingww64clangaarch64fontconfig = '2.15.0-2'
lib_mingww64clangaarch64freetype = '2.13.3-1'
lib_mingww64clangaarch64fribidi = '1.0.16-1'
lib_mingww64clangaarch64gdkpixbuf2 = '2.42.12-3'
lib_mingww64clangaarch64gettextruntime = '0.22.5-2'
lib_mingww64clangaarch64giflib = '5.2.2-1'
lib_mingww64clangaarch64glesheaders = '3.2.r1005.d127c30-1'
lib_mingww64clangaarch64glib2 = '2.82.2-1'
lib_mingww64clangaarch64gobjectintrospectionruntime = '1.82.0-1'
lib_mingww64clangaarch64graphite2 = '1.3.14-3'
lib_mingww64clangaarch64gtk3 = '3.24.43-1'
lib_mingww64clangaarch64gtkupdateiconcache = '3.24.43-1'
lib_mingww64clangaarch64harfbuzz = '10.0.1-1'
lib_mingww64clangaarch64headersgit = '12.0.0.r360.gac299df46-1'
lib_mingww64clangaarch64hicoloricontheme = '0.18-1'
lib_mingww64clangaarch64jbigkit = '2.1-5'
lib_mingww64clangaarch64jsonglib = '1.10.0-1'
lib_mingww64clangaarch64lcms2 = '2.16-1'
lib_mingww64clangaarch64lerc = '4.0.0-1'
lib_mingww64clangaarch64libc = '18.1.8-2'
lib_mingww64clangaarch64libdatrie = '0.2.13-3'
lib_mingww64clangaarch64libdeflate = '1.21-1'
lib_mingww64clangaarch64libepoxy = '1.5.10-5'
lib_mingww64clangaarch64libffi = '3.4.6-1'
lib_mingww64clangaarch64libiconv = '1.17-4'
lib_mingww64clangaarch64libimagequant = '4.3.3-1'
lib_mingww64clangaarch64libjpegturbo = '3.0.4-2'
lib_mingww64clangaarch64libmanglegit = '12.0.0.r360.gac299df46-1'
lib_mingww64clangaarch64libpng = '1.6.44-1'
lib_mingww64clangaarch64libraqm = '0.10.2-1'
lib_mingww64clangaarch64librsvg = '2.59.1-2'
lib_mingww64clangaarch64libspng = '0.7.4-1'
lib_mingww64clangaarch64libsystre = '1.0.1-6'
lib_mingww64clangaarch64libthai = '0.1.29-3'
lib_mingww64clangaarch64libtiff = '4.7.0-1'
lib_mingww64clangaarch64libtre = '0.9.0-1'
lib_mingww64clangaarch64libunwind = '18.1.8-2'
lib_mingww64clangaarch64libvpx = '1.14.1-1'
lib_mingww64clangaarch64libwebp = '1.4.0-1'
lib_mingww64clangaarch64libwinpthreadgit = '12.0.0.r360.gac299df46-1'
lib_mingww64clangaarch64libx264 = '0.164.r3161.a354f11-3'
lib_mingww64clangaarch64libxml2 = '2.12.9-1'
lib_mingww64clangaarch64libyuv = '1887.r2537.a6a2ec65-1'
lib_mingww64clangaarch64lld = '18.1.8-1'
lib_mingww64clangaarch64lldb = '18.1.8-2'
lib_mingww64clangaarch64llvm = '18.1.8-1'
lib_mingww64clangaarch64llvmlibs = '18.1.8-1'
lib_mingww64clangaarch64llvmopenmp = '18.1.8-1'
lib_mingww64clangaarch64lua = '5.4.7-2'
lib_mingww64clangaarch64lz4 = '1.10.0-1'
lib_mingww64clangaarch64lzo2 = '2.10-2'
lib_mingww64clangaarch64make = '4.4.1-3'
lib_mingww64clangaarch64mpdecimal = '4.0.0-1'
lib_mingww64clangaarch64ncurses = '6.5.20240831-1'
lib_mingww64clangaarch64openjpeg2 = '2.5.2-1'
lib_mingww64clangaarch64openssl = '3.3.2-1'
lib_mingww64clangaarch64pango = '1.54.0-1'
lib_mingww64clangaarch64pcre2 = '10.44-1'
lib_mingww64clangaarch64pixman = '0.43.4-1'
lib_mingww64clangaarch64pkgconf = '1~2.3.0-1'
lib_mingww64clangaarch64python = '3.11.10-1'
lib_mingww64clangaarch64pythonbuild = '1.2.2-1'
lib_mingww64clangaarch64pythoncairo = '1.27.0-1'
lib_mingww64clangaarch64pythoncomtypes = '1.4.8-1'
lib_mingww64clangaarch64pythongobject = '3.50.0-1'
lib_mingww64clangaarch64pythoninstaller = '0.7.0-3'
lib_mingww64clangaarch64pythonpackaging = '24.1-2'
lib_mingww64clangaarch64pythonpillow = '11.0.0-1'
lib_mingww64clangaarch64pythonpyopengl = '3.1.7-3'
lib_mingww64clangaarch64pythonpyprojecthooks = '1.1.0-1'
lib_mingww64clangaarch64pythonsetproctitle = '1.3.3-1'
lib_mingww64clangaarch64pythonsetuptools = '75.1.0-2'
lib_mingww64clangaarch64pythonsix = '1.16.0-4'
lib_mingww64clangaarch64readline = '8.2.013-1'
lib_mingww64clangaarch64sharedmimeinfo = '2.4-1'
lib_mingww64clangaarch64sqlite3 = '3.46.1-1'
lib_mingww64clangaarch64tcl = '8.6.13-1'
lib_mingww64clangaarch64termcap = '1.3.1-7'
lib_mingww64clangaarch64tk = '8.6.13-1'
lib_mingww64clangaarch64toolsgit = '12.0.0.r360.gac299df46-1'
lib_mingww64clangaarch64tzdata = '2024b-1'
lib_mingww64clangaarch64wineditline = '2.208-1'
lib_mingww64clangaarch64winpthreadsgit = '12.0.0.r360.gac299df46-1'
lib_mingww64clangaarch64winstorecompatgit = '12.0.0.r360.gac299df46-1'
lib_mingww64clangaarch64xxhash = '0.8.2-2'
lib_mingww64clangaarch64xz = '5.6.3-1'
lib_mingww64clangaarch64zlib = '1.3.1-1'
lib_mingww64clangaarch64zstd = '1.5.6-2'
lib_mintty = '1~3.7.6-1'
lib_mpfr = '4.2.1-1'
lib_msys2keyring = '1~20241007-1'
lib_msys2launcher = '1.5-2'
lib_msys2runtime = '3.5.4-2'
lib_nano = '8.2-1'
lib_ncurses = '6.5.20240831-2'
lib_nettle = '3.10-1'
lib_openssl = '3.3.2-1'
lib_p11kit = '0.25.5-2'
lib_pacman = '6.1.0-8'
lib_pacmancontrib = '1.10.6-1'
lib_pacmanmirrors = '20240523-1'
lib_patch = '2.7.6-2'
lib_perl = '5.38.2-2'
lib_pinentry = '1.3.1-1'
lib_pkgconf = '2.3.0-1'
lib_procpsng = '4.0.4-1'
lib_psmisc = '23.7-1'
lib_rebase = '4.5.0-4'
lib_sed = '4.9-1'
lib_tar = '1.35-2'
lib_texinfo = '7.1.1-1'
lib_texinfotex = '7.1.1-1'
lib_time = '1.9-3'
lib_tzcode = '2024a-1'
lib_utillinux = '2.35.2-4'
lib_vim = '9.1.0740-1'
lib_wget = '1.24.5-2'
lib_which = '2.21-4'
lib_xz = '5.6.3-1'
lib_zlib = '1.3.1-1'
lib_zstd = '1.5.6-1'
